@@ -660,8 +660,6 @@ const NMSettInfoSetting *nmtst_sett_info_settings(void);
 
 typedef enum _nm_packed {
     NM_SETTING_PROPERTY_TO_DBUS_FCN_GPROP_TYPE_DEFAULT = 0,
-    NM_SETTING_PROPERTY_TO_DBUS_FCN_GPROP_TYPE_ENUM,
-    NM_SETTING_PROPERTY_TO_DBUS_FCN_GPROP_TYPE_FLAGS,
     NM_SETTING_PROPERTY_TO_DBUS_FCN_GPROP_TYPE_GARRAY_UINT,
     NM_SETTING_PROPERTY_TO_DBUS_FCN_GPROP_TYPE_STRDICT,
 } NMSettingPropertyToDBusFcnGPropType;
